@@ -1,6 +1,11 @@
 package DBIx::Raw;
-use strict;
-use Mouse;
+
+use 5.008_005;
+our $VERSION = '0.18';
+
+#use strictures 2;
+use Moo;
+use Types::Standard qw/Bool HashRef InstanceOf Str/;
 use DBI;
 use Config::Any;
 use DBIx::Raw::Crypt;
@@ -9,17 +14,21 @@ use List::Util qw/first/;
 use Crypt::Mode::CBC::Easy;
 
 #have an errors file to write to
-has 'dsn'    => ( is => 'rw', isa => 'Any', default => undef);
-has 'user'    => ( is => 'rw', isa => 'Any', default => undef);
-has 'password'    => ( is => 'rw', isa => 'Any', default => undef);
-has 'conf'    => ( is => 'rw', isa => 'Any', default => undef);
-has 'prev_conf'    => ( is => 'rw', isa => 'Str', default => '');
+has 'dsn' => is => 'rw';
+has 'user' => is => 'rw';
+has 'password' => is => 'rw';
+has 'conf' => is => 'rw';
+has 'prev_conf' => (
+    is => 'rw', 
+    isa => Str, 
+    default => '',
+);
 
-has 'crypt'    => ( 
+has 'crypt' => ( 
 	is => 'ro', 
-	isa => 'Crypt::Mode::CBC::Easy',
+	isa => InstanceOf['Crypt::Mode::CBC::Easy'],
 	lazy => 1,
-	default => sub { 
+	builder => sub { 
 		my ($self) = @_;
 		return Crypt::Mode::CBC::Easy->new(key => $self->crypt_key);
 	},
@@ -27,9 +36,9 @@ has 'crypt'    => (
 
 has 'crypt_key' => (
     is => 'rw', 
-    isa => 'Str', 
+    isa => Str, 
     lazy => 1,
-    default => sub {
+    builder => sub {
         my $crypt_key_hex = 'aea77496999d37bf47aedff9c0d44fdf2d2bbfa848ee6652abe9891b43e0f331';
         return pack "H*", $crypt_key_hex;
     }, 
@@ -37,40 +46,40 @@ has 'crypt_key' => (
 
 has use_old_crypt => (
     is => 'rw',
-    isa => 'Bool',
+    isa => Bool,
     default => undef,
 );
 
 has 'old_crypt_key' => (
     is => 'rw', 
-    isa => 'Str', 
+    isa => Str, 
     lazy => 1,
     default => '6883868834006296591264051568595813693328016796531185824375212916576042669669556288781800326542091901603033335703884439231366552922364658270813734165084102xfasdfa8823423sfasdfalkj!@#$$CCCFFF!09xxxxlai3847lol13234408!!@#$_+-083dxje380-=0'
 );
 
-has 'old_crypt'    => ( 
+has 'old_crypt' => ( 
 	is => 'ro', 
-	isa => 'DBIx::Raw::Crypt', 
+	isa => InstanceOf['DBIx::Raw::Crypt'], 
 	lazy => 1,
-	default => sub { 
+	builder => sub { 
 		my ($self) = @_;
 		return DBIx::Raw::Crypt->new( { secret => $self->old_crypt_key });
 	},
 );
 
-has 'sth'    => ( is => 'rw', isa => 'Any', default => undef); #LAST STH USED
+# LAST STH USED
+has 'sth' => is => 'rw';
 
 #find out what DBH is specifically
-has 'dbh'    => ( 
+has 'dbh' => ( 
 	is => 'rw', 
-	isa => 'Any', 
 	lazy => 1, 
 	default => sub { shift->connect }
 );
 
 has 'keys' => (
 	is => 'ro', 
-	isa=>'HashRef[Str]',
+	isa => HashRef[Str],
 	default => sub { {
 		query => 1,
 		vals => 1,
@@ -96,14 +105,6 @@ sub BUILD {
 
 DBIx::Raw - Maintain control of SQL queries while still having a layer of abstraction above DBI
 
-=head1 VERSION
-
-Version 0.17
-
-=cut
-
-our $VERSION = '0.17';
-
 =head1 SYNOPSIS
 
 DBIx::Raw allows you to have complete control over your SQL, while still providing useful functionality so you don't have to deal directly with L<DBI>.
@@ -1503,9 +1504,6 @@ Please report any bugs or feature requests to C<bug-dbix-raw at rt.cpan.org>, or
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBIx-Raw>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -1540,47 +1538,11 @@ L<http://search.cpan.org/dist/DBIx-Raw/>
 
 Special thanks to Jay Davis who wrote a lot of the original code that this module is based on.
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2014 Adam Hopkins.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+=head1 LICENSE
 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
-1; # End of DBIx::Raw
+1;
